@@ -1,6 +1,6 @@
 from django.contrib.contenttypes.models import ContentType
 from django.test import TestCase
-from entity import turn_on_syncing, turn_off_syncing
+from entity.signal_handlers import turn_on_syncing, turn_off_syncing
 from entity.models import Entity, EntityKind
 
 
@@ -33,5 +33,5 @@ class EntityTestCase(TestCase):
             entity_type=entity_type, entity_id=model_obj.id,
             entity_kind=EntityKind.objects.get_or_create(
                 name='{0}__{1}'.format(entity_type.app_label, entity_type.model),
-                defaults={'display_name': unicode(entity_type)}
+                defaults={'display_name': u'{0}'.format(entity_type)}
             )[0])
